Frontend modules — polyfemos 0.3.29 documentation

# Frontend modules

`polyfemos.front.alertreader` | Functions for reading state of health alert files (‘*.alert’)
`polyfemos.front.colors` | Contains all color values for polyfemos
`polyfemos.front.flask_config` | Flask configuration class
`polyfemos.front.forms` | Web forms
`polyfemos.front.main` | Frontend of polyfemos
`polyfemos.front.request` | Collection of miscellanous functions
`polyfemos.front.sohplot.datacontainer` | Classes for handling datapoints
`polyfemos.front.sohplot.offsets` | Contains class `UWVOffsets`.
`polyfemos.front.sohplot.outfilefields` | Type structure for ‘*.stf’ file header fields and data rows, and for ‘*.alert’ and ‘*.csv’ file data rows.
`polyfemos.front.sohplot.sohplot` | Class `SOHPlot` for reading and plotting state of health data
`polyfemos.front.trafficmonitor` | Monitors and limits website usage
`polyfemos.front.userdef` | Provides config values from YAML files